package App::cpanoutdated;
use strict;
use warnings;
our $VERSION = "0.23";
1;
__END__

=head1 DESCRIPTION

see L<cpan-outdated>.

=head1 AUTHOR

Tokuhiro Matsuno

=head1 LICENSE

Copyright (C) 2009 Tokuhiro Matsuno.

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=head1 SEE ALSO

L<CPAN>

L<App::cpanminus>

=cut
